# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/labelingpipeline/v1/labelingpipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQgithub.com/metaprov/modelaapi/services/labelingpipeline/v1/labelingpipeline.proto\x12:github.com.metaprov.modelaapi.services.labelingpipeline.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x8d\x02\n\x1bListLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12s\n\x06labels\x18\x02 \x03(\x0b\x32\x63.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x1cListLabelingPipelineResponse\x12\x65\n\x11labelingpipelines\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x81\x01\n\x1d\x43reateLabelingPipelineRequest\x12`\n\x10labelingpipeline\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\" \n\x1e\x43reateLabelingPipelineResponse\"\xb1\x01\n\x1dUpdateLabelingPipelineRequest\x12`\n\x10labelingpipeline\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x1eUpdateLabelingPipelineResponse\"=\n\x1aGetLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8d\x01\n\x1bGetLabelingPipelineResponse\x12`\n\x10labelingpipeline\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteLabelingPipelineResponse\"\x1f\n\x1dPauseLabelingPipelineResponse\"?\n\x1cPauseLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1eResumeLabelingPipelineResponse\"@\n\x1dResumeLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xc5\x0e\n\x17LabelingPipelineService\x12\xf2\x01\n\x15ListLabelingPipelines\x12W.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest\x1aX.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/labelpipelines/{namespace}\x12\xee\x01\n\x16\x43reateLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/labelpipelines:\x01*\x12\xf5\x01\n\x13GetLabelingPipeline\x12V.github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest\x1aW.github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/labelpipelines/{namespace}/{name}\x12\xb5\x02\n\x16UpdateLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineResponse\"d\x82\xd3\xe4\x93\x02^\x1aY/v1/labelpipelines/{labelingpipeline.metadata.namespace}/{labelingpipeline.metadata.name}:\x01*\x12\x81\x02\n\x16\x44\x65leteLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineResponse\"0\x82\xd3\xe4\x93\x02**(/v1/labelingpipelines/{namespace}/{name}\x12\x84\x02\n\x15PauseLabelingPipeline\x12X.github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest\x1aY.github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineResponse\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/labelpipelines/{namespace}/{name}:pause:\x01*\x12\x88\x02\n\x16ResumeLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineResponse\"7\x82\xd3\xe4\x93\x02\x31\",/v1/labelpipelines/{namespace}/{name}:resume:\x01*B<Z:github.com/metaprov/modelaapi/services/labelingpipeline/v1b\x06proto3')



_LISTLABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ListLabelingPipelineRequest']
_LISTLABELINGPIPELINEREQUEST_LABELSENTRY = _LISTLABELINGPIPELINEREQUEST.nested_types_by_name['LabelsEntry']
_LISTLABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ListLabelingPipelineResponse']
_CREATELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRequest']
_CREATELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineResponse']
_UPDATELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRequest']
_UPDATELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineResponse']
_GETLABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetLabelingPipelineRequest']
_GETLABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['GetLabelingPipelineResponse']
_DELETELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRequest']
_DELETELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineResponse']
_PAUSELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['PauseLabelingPipelineResponse']
_PAUSELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['PauseLabelingPipelineRequest']
_RESUMELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ResumeLabelingPipelineResponse']
_RESUMELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ResumeLabelingPipelineRequest']
ListLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABELINGPIPELINEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRequest)
_sym_db.RegisterMessage(ListLabelingPipelineRequest.LabelsEntry)

ListLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelineResponse)

CreateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRequest)

CreateLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineResponse)

UpdateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRequest)

UpdateLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineResponse)

GetLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRequest)

GetLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(GetLabelingPipelineResponse)

DeleteLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRequest)

DeleteLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineResponse)

PauseLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('PauseLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(PauseLabelingPipelineResponse)

PauseLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('PauseLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(PauseLabelingPipelineRequest)

ResumeLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(ResumeLabelingPipelineResponse)

ResumeLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(ResumeLabelingPipelineRequest)

_LABELINGPIPELINESERVICE = DESCRIPTOR.services_by_name['LabelingPipelineService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/metaprov/modelaapi/services/labelingpipeline/v1'
  _LISTLABELINGPIPELINEREQUEST_LABELSENTRY._options = None
  _LISTLABELINGPIPELINEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LABELINGPIPELINESERVICE.methods_by_name['ListLabelingPipelines']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['ListLabelingPipelines']._serialized_options = b'\202\323\344\223\002 \022\036/v1/labelpipelines/{namespace}'
  _LABELINGPIPELINESERVICE.methods_by_name['CreateLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['CreateLabelingPipeline']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/labelpipelines:\001*'
  _LABELINGPIPELINESERVICE.methods_by_name['GetLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['GetLabelingPipeline']._serialized_options = b'\202\323\344\223\002\'\022%/v1/labelpipelines/{namespace}/{name}'
  _LABELINGPIPELINESERVICE.methods_by_name['UpdateLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['UpdateLabelingPipeline']._serialized_options = b'\202\323\344\223\002^\032Y/v1/labelpipelines/{labelingpipeline.metadata.namespace}/{labelingpipeline.metadata.name}:\001*'
  _LABELINGPIPELINESERVICE.methods_by_name['DeleteLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['DeleteLabelingPipeline']._serialized_options = b'\202\323\344\223\002**(/v1/labelingpipelines/{namespace}/{name}'
  _LABELINGPIPELINESERVICE.methods_by_name['PauseLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['PauseLabelingPipeline']._serialized_options = b'\202\323\344\223\0020\"+/v1/labelpipelines/{namespace}/{name}:pause:\001*'
  _LABELINGPIPELINESERVICE.methods_by_name['ResumeLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['ResumeLabelingPipeline']._serialized_options = b'\202\323\344\223\0021\",/v1/labelpipelines/{namespace}/{name}:resume:\001*'
  _LISTLABELINGPIPELINEREQUEST._serialized_start=280
  _LISTLABELINGPIPELINEREQUEST._serialized_end=549
  _LISTLABELINGPIPELINEREQUEST_LABELSENTRY._serialized_start=504
  _LISTLABELINGPIPELINEREQUEST_LABELSENTRY._serialized_end=549
  _LISTLABELINGPIPELINERESPONSE._serialized_start=552
  _LISTLABELINGPIPELINERESPONSE._serialized_end=710
  _CREATELABELINGPIPELINEREQUEST._serialized_start=713
  _CREATELABELINGPIPELINEREQUEST._serialized_end=842
  _CREATELABELINGPIPELINERESPONSE._serialized_start=844
  _CREATELABELINGPIPELINERESPONSE._serialized_end=876
  _UPDATELABELINGPIPELINEREQUEST._serialized_start=879
  _UPDATELABELINGPIPELINEREQUEST._serialized_end=1056
  _UPDATELABELINGPIPELINERESPONSE._serialized_start=1058
  _UPDATELABELINGPIPELINERESPONSE._serialized_end=1090
  _GETLABELINGPIPELINEREQUEST._serialized_start=1092
  _GETLABELINGPIPELINEREQUEST._serialized_end=1153
  _GETLABELINGPIPELINERESPONSE._serialized_start=1156
  _GETLABELINGPIPELINERESPONSE._serialized_end=1297
  _DELETELABELINGPIPELINEREQUEST._serialized_start=1299
  _DELETELABELINGPIPELINEREQUEST._serialized_end=1363
  _DELETELABELINGPIPELINERESPONSE._serialized_start=1365
  _DELETELABELINGPIPELINERESPONSE._serialized_end=1397
  _PAUSELABELINGPIPELINERESPONSE._serialized_start=1399
  _PAUSELABELINGPIPELINERESPONSE._serialized_end=1430
  _PAUSELABELINGPIPELINEREQUEST._serialized_start=1432
  _PAUSELABELINGPIPELINEREQUEST._serialized_end=1495
  _RESUMELABELINGPIPELINERESPONSE._serialized_start=1497
  _RESUMELABELINGPIPELINERESPONSE._serialized_end=1529
  _RESUMELABELINGPIPELINEREQUEST._serialized_start=1531
  _RESUMELABELINGPIPELINEREQUEST._serialized_end=1595
  _LABELINGPIPELINESERVICE._serialized_start=1598
  _LABELINGPIPELINESERVICE._serialized_end=3459
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/api/rbac/v1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"k8s.io/api/rbac/v1/generated.proto\x12\x12k8s.io.api.rbac.v1\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"d\n\x0f\x41ggregationRule\x12Q\n\x14\x63lusterRoleSelectors\x18\x01 \x03(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\"\xbe\x01\n\x0b\x43lusterRole\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x05rules\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.rbac.v1.PolicyRule\x12<\n\x0f\x61ggregationRule\x18\x03 \x01(\x0b\x32#.k8s.io.api.rbac.v1.AggregationRule\"\xb5\x01\n\x12\x43lusterRoleBinding\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x08subjects\x18\x02 \x03(\x0b\x32\x1b.k8s.io.api.rbac.v1.Subject\x12,\n\x07roleRef\x18\x03 \x01(\x0b\x32\x1b.k8s.io.api.rbac.v1.RoleRef\"\x91\x01\n\x16\x43lusterRoleBindingList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.k8s.io.api.rbac.v1.ClusterRoleBinding\"\x83\x01\n\x0f\x43lusterRoleList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.k8s.io.api.rbac.v1.ClusterRole\"q\n\nPolicyRule\x12\r\n\x05verbs\x18\x01 \x03(\t\x12\x11\n\tapiGroups\x18\x02 \x03(\t\x12\x11\n\tresources\x18\x03 \x03(\t\x12\x15\n\rresourceNames\x18\x04 \x03(\t\x12\x17\n\x0fnonResourceURLs\x18\x05 \x03(\t\"y\n\x04Role\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x05rules\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.rbac.v1.PolicyRule\"\xae\x01\n\x0bRoleBinding\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x08subjects\x18\x02 \x03(\x0b\x32\x1b.k8s.io.api.rbac.v1.Subject\x12,\n\x07roleRef\x18\x03 \x01(\x0b\x32\x1b.k8s.io.api.rbac.v1.RoleRef\"\x83\x01\n\x0fRoleBindingList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.k8s.io.api.rbac.v1.RoleBinding\"u\n\x08RoleList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.k8s.io.api.rbac.v1.Role\"7\n\x07RoleRef\x12\x10\n\x08\x61piGroup\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"J\n\x07Subject\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x10\n\x08\x61piGroup\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\tB\x14Z\x12k8s.io/api/rbac/v1')



_AGGREGATIONRULE = DESCRIPTOR.message_types_by_name['AggregationRule']
_CLUSTERROLE = DESCRIPTOR.message_types_by_name['ClusterRole']
_CLUSTERROLEBINDING = DESCRIPTOR.message_types_by_name['ClusterRoleBinding']
_CLUSTERROLEBINDINGLIST = DESCRIPTOR.message_types_by_name['ClusterRoleBindingList']
_CLUSTERROLELIST = DESCRIPTOR.message_types_by_name['ClusterRoleList']
_POLICYRULE = DESCRIPTOR.message_types_by_name['PolicyRule']
_ROLE = DESCRIPTOR.message_types_by_name['Role']
_ROLEBINDING = DESCRIPTOR.message_types_by_name['RoleBinding']
_ROLEBINDINGLIST = DESCRIPTOR.message_types_by_name['RoleBindingList']
_ROLELIST = DESCRIPTOR.message_types_by_name['RoleList']
_ROLEREF = DESCRIPTOR.message_types_by_name['RoleRef']
_SUBJECT = DESCRIPTOR.message_types_by_name['Subject']
AggregationRule = _reflection.GeneratedProtocolMessageType('AggregationRule', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATIONRULE,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.AggregationRule)
  })
_sym_db.RegisterMessage(AggregationRule)

ClusterRole = _reflection.GeneratedProtocolMessageType('ClusterRole', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLE,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.ClusterRole)
  })
_sym_db.RegisterMessage(ClusterRole)

ClusterRoleBinding = _reflection.GeneratedProtocolMessageType('ClusterRoleBinding', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLEBINDING,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.ClusterRoleBinding)
  })
_sym_db.RegisterMessage(ClusterRoleBinding)

ClusterRoleBindingList = _reflection.GeneratedProtocolMessageType('ClusterRoleBindingList', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLEBINDINGLIST,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.ClusterRoleBindingList)
  })
_sym_db.RegisterMessage(ClusterRoleBindingList)

ClusterRoleList = _reflection.GeneratedProtocolMessageType('ClusterRoleList', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLELIST,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.ClusterRoleList)
  })
_sym_db.RegisterMessage(ClusterRoleList)

PolicyRule = _reflection.GeneratedProtocolMessageType('PolicyRule', (_message.Message,), {
  'DESCRIPTOR' : _POLICYRULE,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.PolicyRule)
  })
_sym_db.RegisterMessage(PolicyRule)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.Role)
  })
_sym_db.RegisterMessage(Role)

RoleBinding = _reflection.GeneratedProtocolMessageType('RoleBinding', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDING,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.RoleBinding)
  })
_sym_db.RegisterMessage(RoleBinding)

RoleBindingList = _reflection.GeneratedProtocolMessageType('RoleBindingList', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGLIST,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.RoleBindingList)
  })
_sym_db.RegisterMessage(RoleBindingList)

RoleList = _reflection.GeneratedProtocolMessageType('RoleList', (_message.Message,), {
  'DESCRIPTOR' : _ROLELIST,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.RoleList)
  })
_sym_db.RegisterMessage(RoleList)

RoleRef = _reflection.GeneratedProtocolMessageType('RoleRef', (_message.Message,), {
  'DESCRIPTOR' : _ROLEREF,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.RoleRef)
  })
_sym_db.RegisterMessage(RoleRef)

Subject = _reflection.GeneratedProtocolMessageType('Subject', (_message.Message,), {
  'DESCRIPTOR' : _SUBJECT,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.Subject)
  })
_sym_db.RegisterMessage(Subject)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\022k8s.io/api/rbac/v1'
  _AGGREGATIONRULE._serialized_start=217
  _AGGREGATIONRULE._serialized_end=317
  _CLUSTERROLE._serialized_start=320
  _CLUSTERROLE._serialized_end=510
  _CLUSTERROLEBINDING._serialized_start=513
  _CLUSTERROLEBINDING._serialized_end=694
  _CLUSTERROLEBINDINGLIST._serialized_start=697
  _CLUSTERROLEBINDINGLIST._serialized_end=842
  _CLUSTERROLELIST._serialized_start=845
  _CLUSTERROLELIST._serialized_end=976
  _POLICYRULE._serialized_start=978
  _POLICYRULE._serialized_end=1091
  _ROLE._serialized_start=1093
  _ROLE._serialized_end=1214
  _ROLEBINDING._serialized_start=1217
  _ROLEBINDING._serialized_end=1391
  _ROLEBINDINGLIST._serialized_start=1394
  _ROLEBINDINGLIST._serialized_end=1525
  _ROLELIST._serialized_start=1527
  _ROLELIST._serialized_end=1644
  _ROLEREF._serialized_start=1646
  _ROLEREF._serialized_end=1701
  _SUBJECT._serialized_start=1703
  _SUBJECT._serialized_end=1777
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/notifier/v1/notifier.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/notifier/v1/notifier.proto\x12\x32github.com.metaprov.modelaapi.services.notifier.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xf7\x01\n\x14ListNotifiersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x15ListNotifiersResponse\x12V\n\tnotifiers\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.NotifierList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x12\n\x10NotifierResponse\"j\n\x15\x43reateNotifierRequest\x12Q\n\x08notifier\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x18\n\x16\x43reateNotifierResponse\"\x9a\x01\n\x15UpdateNotifierRequest\x12Q\n\x08notifier\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x18\n\x16UpdateNotifierResponse\"5\n\x12GetNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x13GetNotifierResponse\x12Q\n\x08notifier\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"8\n\x15\x44\x65leteNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteNotifierResponse2\xb9\x08\n\x0fNotifierService\x12\xc7\x01\n\rListNotifiers\x12H.github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest\x1aI.github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/notifiers/{namespace}\x12\xc1\x01\n\x0e\x43reateNotifier\x12I.github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierRequest\x1aJ.github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/notifiers:\x01*\x12\xc8\x01\n\x0bGetNotifier\x12\x46.github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierRequest\x1aG.github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/notifiers/{namespace}/{name}\x12\xf8\x01\n\x0eUpdateNotifier\x12I.github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierRequest\x1aJ.github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierResponse\"O\x82\xd3\xe4\x93\x02I\x1a\x44/v1/notifiers/{notifier.metadata.namespace}/{notifier.metadata.name}:\x01*\x12\xd1\x01\n\x0e\x44\x65leteNotifier\x12I.github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierRequest\x1aJ.github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierResponse\"(\x82\xd3\xe4\x93\x02\"* /v1/notifiers/{namespace}/{name}B4Z2github.com/metaprov/modelaapi/services/notifier/v1b\x06proto3')



_LISTNOTIFIERSREQUEST = DESCRIPTOR.message_types_by_name['ListNotifiersRequest']
_LISTNOTIFIERSREQUEST_LABELSENTRY = _LISTNOTIFIERSREQUEST.nested_types_by_name['LabelsEntry']
_LISTNOTIFIERSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotifiersResponse']
_NOTIFIERRESPONSE = DESCRIPTOR.message_types_by_name['NotifierResponse']
_CREATENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['CreateNotifierRequest']
_CREATENOTIFIERRESPONSE = DESCRIPTOR.message_types_by_name['CreateNotifierResponse']
_UPDATENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotifierRequest']
_UPDATENOTIFIERRESPONSE = DESCRIPTOR.message_types_by_name['UpdateNotifierResponse']
_GETNOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['GetNotifierRequest']
_GETNOTIFIERRESPONSE = DESCRIPTOR.message_types_by_name['GetNotifierResponse']
_DELETENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotifierRequest']
_DELETENOTIFIERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteNotifierResponse']
ListNotifiersRequest = _reflection.GeneratedProtocolMessageType('ListNotifiersRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTNOTIFIERSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTNOTIFIERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest)
  })
_sym_db.RegisterMessage(ListNotifiersRequest)
_sym_db.RegisterMessage(ListNotifiersRequest.LabelsEntry)

ListNotifiersResponse = _reflection.GeneratedProtocolMessageType('ListNotifiersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTIFIERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersResponse)
  })
_sym_db.RegisterMessage(ListNotifiersResponse)

NotifierResponse = _reflection.GeneratedProtocolMessageType('NotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.NotifierResponse)
  })
_sym_db.RegisterMessage(NotifierResponse)

CreateNotifierRequest = _reflection.GeneratedProtocolMessageType('CreateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierRequest)
  })
_sym_db.RegisterMessage(CreateNotifierRequest)

CreateNotifierResponse = _reflection.GeneratedProtocolMessageType('CreateNotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierResponse)
  })
_sym_db.RegisterMessage(CreateNotifierResponse)

UpdateNotifierRequest = _reflection.GeneratedProtocolMessageType('UpdateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierRequest)
  })
_sym_db.RegisterMessage(UpdateNotifierRequest)

UpdateNotifierResponse = _reflection.GeneratedProtocolMessageType('UpdateNotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierResponse)
  })
_sym_db.RegisterMessage(UpdateNotifierResponse)

GetNotifierRequest = _reflection.GeneratedProtocolMessageType('GetNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierRequest)
  })
_sym_db.RegisterMessage(GetNotifierRequest)

GetNotifierResponse = _reflection.GeneratedProtocolMessageType('GetNotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierResponse)
  })
_sym_db.RegisterMessage(GetNotifierResponse)

DeleteNotifierRequest = _reflection.GeneratedProtocolMessageType('DeleteNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierRequest)
  })
_sym_db.RegisterMessage(DeleteNotifierRequest)

DeleteNotifierResponse = _reflection.GeneratedProtocolMessageType('DeleteNotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierResponse)
  })
_sym_db.RegisterMessage(DeleteNotifierResponse)

_NOTIFIERSERVICE = DESCRIPTOR.services_by_name['NotifierService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/notifier/v1'
  _LISTNOTIFIERSREQUEST_LABELSENTRY._options = None
  _LISTNOTIFIERSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _NOTIFIERSERVICE.methods_by_name['ListNotifiers']._options = None
  _NOTIFIERSERVICE.methods_by_name['ListNotifiers']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/notifiers/{namespace}'
  _NOTIFIERSERVICE.methods_by_name['CreateNotifier']._options = None
  _NOTIFIERSERVICE.methods_by_name['CreateNotifier']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/notifiers:\001*'
  _NOTIFIERSERVICE.methods_by_name['GetNotifier']._options = None
  _NOTIFIERSERVICE.methods_by_name['GetNotifier']._serialized_options = b'\202\323\344\223\002\"\022 /v1/notifiers/{namespace}/{name}'
  _NOTIFIERSERVICE.methods_by_name['UpdateNotifier']._options = None
  _NOTIFIERSERVICE.methods_by_name['UpdateNotifier']._serialized_options = b'\202\323\344\223\002I\032D/v1/notifiers/{notifier.metadata.namespace}/{notifier.metadata.name}:\001*'
  _NOTIFIERSERVICE.methods_by_name['DeleteNotifier']._options = None
  _NOTIFIERSERVICE.methods_by_name['DeleteNotifier']._serialized_options = b'\202\323\344\223\002\"* /v1/notifiers/{namespace}/{name}'
  _LISTNOTIFIERSREQUEST._serialized_start=320
  _LISTNOTIFIERSREQUEST._serialized_end=567
  _LISTNOTIFIERSREQUEST_LABELSENTRY._serialized_start=522
  _LISTNOTIFIERSREQUEST_LABELSENTRY._serialized_end=567
  _LISTNOTIFIERSRESPONSE._serialized_start=570
  _LISTNOTIFIERSRESPONSE._serialized_end=706
  _NOTIFIERRESPONSE._serialized_start=708
  _NOTIFIERRESPONSE._serialized_end=726
  _CREATENOTIFIERREQUEST._serialized_start=728
  _CREATENOTIFIERREQUEST._serialized_end=834
  _CREATENOTIFIERRESPONSE._serialized_start=836
  _CREATENOTIFIERRESPONSE._serialized_end=860
  _UPDATENOTIFIERREQUEST._serialized_start=863
  _UPDATENOTIFIERREQUEST._serialized_end=1017
  _UPDATENOTIFIERRESPONSE._serialized_start=1019
  _UPDATENOTIFIERRESPONSE._serialized_end=1043
  _GETNOTIFIERREQUEST._serialized_start=1045
  _GETNOTIFIERREQUEST._serialized_end=1098
  _GETNOTIFIERRESPONSE._serialized_start=1100
  _GETNOTIFIERRESPONSE._serialized_end=1218
  _DELETENOTIFIERREQUEST._serialized_start=1220
  _DELETENOTIFIERREQUEST._serialized_end=1276
  _DELETENOTIFIERRESPONSE._serialized_start=1278
  _DELETENOTIFIERRESPONSE._serialized_end=1302
  _NOTIFIERSERVICE._serialized_start=1305
  _NOTIFIERSERVICE._serialized_end=2386
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.datapipeline.v1 import datapipeline_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2


class DataPipelineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataPipelines = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/ListDataPipelines',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.ListDataPipelinesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.ListDataPipelinesResponse.FromString,
                )
        self.CreateDataPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/CreateDataPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.CreateDataPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.CreateDataPipelineResponse.FromString,
                )
        self.GetDataPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/GetDataPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.GetDataPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.GetDataPipelineResponse.FromString,
                )
        self.UpdateDataPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/UpdateDataPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.UpdateDataPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.UpdateDataPipelineResponse.FromString,
                )
        self.DeleteDataPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/DeleteDataPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.DeleteDataPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.DeleteDataPipelineResponse.FromString,
                )
        self.RunDataPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/RunDataPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.RunDataPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.RunDataPipelineResponse.FromString,
                )


class DataPipelineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataPipelines(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunDataPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataPipelineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataPipelines': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataPipelines,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.ListDataPipelinesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.ListDataPipelinesResponse.SerializeToString,
            ),
            'CreateDataPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.CreateDataPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.CreateDataPipelineResponse.SerializeToString,
            ),
            'GetDataPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.GetDataPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.GetDataPipelineResponse.SerializeToString,
            ),
            'UpdateDataPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.UpdateDataPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.UpdateDataPipelineResponse.SerializeToString,
            ),
            'DeleteDataPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.DeleteDataPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.DeleteDataPipelineResponse.SerializeToString,
            ),
            'RunDataPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.RunDataPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.RunDataPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.RunDataPipelineResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataPipelineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataPipelines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/ListDataPipelines',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.ListDataPipelinesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.ListDataPipelinesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/CreateDataPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.CreateDataPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.CreateDataPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/GetDataPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.GetDataPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.GetDataPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/UpdateDataPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.UpdateDataPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.UpdateDataPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/DeleteDataPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.DeleteDataPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.DeleteDataPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunDataPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService/RunDataPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.RunDataPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipeline_dot_v1_dot_datapipeline__pb2.RunDataPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# custom transformer
#
#
# Author:   Tomer Sagi <tomer.sagi@metaprov.edu>
#
# Copyright (C) 2019 metaprov.com
# For license information, see LICENSE.txt


##########################################################################
# Imports
##########################################################################

from sklearn.base import BaseEstimator, TransformerMixin
import pandas as pd
import numpy as np


##########################################################################
# Remove outliers
##########################################################################


class RemoveOutliers(BaseEstimator, TransformerMixin):
    def fit(self, X, y=None):
        df = pd.DataFrame(X)
        self.mask = df.quantile(q=np.array([0.05, 0.95]), axis=0)
        return self

    def transform(self, X, y=None):
        df = pd.DataFrame(X)
        df = df[(df > self.mask.iloc[0, :]) & (df < self.mask.iloc[1, :])]
        return df


#############################################################################
# Feature filter
#############################################################################


class FeatureFilters(BaseEstimator, TransformerMixin):
    def __init__(self, features_to_drop=None):
        self.features = features_to_drop

    def fit(self, X, y=None):
        return self

    def transform(self, X):
        # encode labels
        X = X.copy()
        X = X.drop(self.features, axis=1)

        return X


################################################################################
# Drop Correlated Features
################################################################################


class DropCorrelated(BaseEstimator, TransformerMixin):
    """drops correlated values above a threshold provided"""

    def __init__(self, threshold=0.95):
        self.threshold = threshold
        self.columns_to_drop = None

    def fit(self, X, y=None):
        data = pd.concat([X, y], axis=1)
        correlation_matrix = data.corr().abs()
        corr_selection = correlation_matrix.where(
            np.triu(np.ones(correlation_matrix.shape), k=1).astype(np.bool)
        )
        self.columns_to_drop = [
            column
            for column in corr_selection.columns
            if any(corr_selection[column] > self.threshold)
        ]
        return self

    def transform(self, X):
        # encode labels
        X = X.copy()
        X = X.drop(self.columns_to_drop, axis=1)
        return X


################################################################################
# Extract date time
################################################################################


class DatetimeFeatureExtractor(BaseEstimator, TransformerMixin):
    def __init__(self, variables):
        self.variables = variables

    def fit(self, X, y=None):
        return self

    def transform(self, X):
        # encode labels
        for name in self.variables:
            # For each datetime var, extact the datetime parameters
            X[name + "_year"] = X.dt.year
            X[name + "_month"] = X.dt.month
            X[name + "_day"] = X.dt.day
            X[name + "_hour"] = X.dt.hour
            X[name + "_minute"] = X.dt.minute
            X[name + "_second"] = X.dt.second
            X[name + "_week"] = X.dt.week
            X[name + "_weekofyear"] = X.dt.weekofyear
            X[name + "_dayofweek"] = X.dt.dayofweek
            X[name + "_weekday"] = X.dt.weekday
            X[name + "_dayofyear"] = X.dt.dayofyear
            X[name + "_quarter"] = X.dt.quarter
            X[name + "_is_monthr_start"] = X.dt.is_month_start
            X[name + "_is_monthr_end"] = X.dt.is_month_end
        return X


##################################################################
# Identity transformer
##################################################################


class IdentityTransformer(BaseEstimator, TransformerMixin):
    def __init__(self):
        pass

    def fit(self, input_array, y=None):
        return self

    def transform(self, input_array, y=None):
        return input_array * 1



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.sqlqueryrun.v1 import sqlqueryrun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2


class SqlQueryRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSqlQuerieRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/ListSqlQuerieRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.ListSqlQueryRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.ListSqlQueryRunsResponse.FromString,
                )
        self.CreateSqlQueryRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/CreateSqlQueryRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.CreateSqlQueryRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.CreateSqlQueryRunResponse.FromString,
                )
        self.GetSqlQueryRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/GetSqlQueryRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.GetSqlQueryRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.GetSqlQueryRunResponse.FromString,
                )
        self.UpdateSqlQueryRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/UpdateSqlQueryRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.UpdateSqlQueryRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.UpdateSqlQueryRunResponse.FromString,
                )
        self.DeleteSqlQueryRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/DeleteSqlQueryRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.DeleteSqlQueryRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.DeleteSqlQueryRunResponse.FromString,
                )
        self.RunSqlQueryRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/RunSqlQueryRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.RunSqlQueryRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.RunSqlQueryRunResponse.FromString,
                )


class SqlQueryRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListSqlQuerieRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSqlQueryRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSqlQueryRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSqlQueryRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSqlQueryRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunSqlQueryRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SqlQueryRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListSqlQuerieRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSqlQuerieRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.ListSqlQueryRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.ListSqlQueryRunsResponse.SerializeToString,
            ),
            'CreateSqlQueryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSqlQueryRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.CreateSqlQueryRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.CreateSqlQueryRunResponse.SerializeToString,
            ),
            'GetSqlQueryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSqlQueryRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.GetSqlQueryRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.GetSqlQueryRunResponse.SerializeToString,
            ),
            'UpdateSqlQueryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSqlQueryRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.UpdateSqlQueryRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.UpdateSqlQueryRunResponse.SerializeToString,
            ),
            'DeleteSqlQueryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSqlQueryRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.DeleteSqlQueryRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.DeleteSqlQueryRunResponse.SerializeToString,
            ),
            'RunSqlQueryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.RunSqlQueryRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.RunSqlQueryRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.RunSqlQueryRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SqlQueryRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListSqlQuerieRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/ListSqlQuerieRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.ListSqlQueryRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.ListSqlQueryRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSqlQueryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/CreateSqlQueryRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.CreateSqlQueryRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.CreateSqlQueryRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSqlQueryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/GetSqlQueryRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.GetSqlQueryRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.GetSqlQueryRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSqlQueryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/UpdateSqlQueryRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.UpdateSqlQueryRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.UpdateSqlQueryRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSqlQueryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/DeleteSqlQueryRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.DeleteSqlQueryRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.DeleteSqlQueryRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunSqlQueryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService/RunSqlQueryRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.RunSqlQueryRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlqueryrun_dot_v1_dot_sqlqueryrun__pb2.RunSqlQueryRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/datapipeline/v1/datapipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIgithub.com/metaprov/modelaapi/services/datapipeline/v1/datapipeline.proto\x12\x36github.com.metaprov.modelaapi.services.datapipeline.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x83\x02\n\x18ListDataPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12l\n\x06labels\x18\x02 \x03(\x0b\x32\\.github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\x01\n\x19ListDataPipelinesResponse\x12]\n\rdatapipelines\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"u\n\x19\x43reateDataPipelineRequest\x12X\n\x0c\x64\x61tapipeline\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x1c\n\x1a\x43reateDataPipelineResponse\"\xa5\x01\n\x19UpdateDataPipelineRequest\x12X\n\x0c\x64\x61tapipeline\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1c\n\x1aUpdateDataPipelineResponse\"9\n\x16GetDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x01\n\x17GetDataPipelineResponse\x12X\n\x0c\x64\x61tapipeline\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"9\n\x16RunDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"}\n\x17RunDataPipelineResponse\x12T\n\x08pipeline\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"<\n\x19\x44\x65leteDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x44\x65leteDataPipelineResponse2\xa4\x0b\n\x13\x44\x61taPipelineService\x12\xdf\x01\n\x11ListDataPipelines\x12P.github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest\x1aQ.github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/datapipelines/{namespace}\x12\xd9\x01\n\x12\x43reateDataPipeline\x12Q.github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineRequest\x1aR.github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/datapipelines:\x01*\x12\xe0\x01\n\x0fGetDataPipeline\x12N.github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineRequest\x1aO.github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/datapipelines/{namespace}/{name}\x12\x98\x02\n\x12UpdateDataPipeline\x12Q.github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineRequest\x1aR.github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineResponse\"[\x82\xd3\xe4\x93\x02U\x1aP/v1/datapipelines/{datapipeline.metadata.namespace}/{datapipeline.metadata.name}:\x01*\x12\xe9\x01\n\x12\x44\x65leteDataPipeline\x12Q.github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineRequest\x1aR.github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineResponse\",\x82\xd3\xe4\x93\x02&*$/v1/datapipelines/{namespace}/{name}\x12\xe4\x01\n\x0fRunDataPipeline\x12N.github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineRequest\x1aO.github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/datapipelines/{namespace}/{name}:runB8Z6github.com/metaprov/modelaapi/services/datapipeline/v1b\x06proto3')



_LISTDATAPIPELINESREQUEST = DESCRIPTOR.message_types_by_name['ListDataPipelinesRequest']
_LISTDATAPIPELINESREQUEST_LABELSENTRY = _LISTDATAPIPELINESREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATAPIPELINESRESPONSE = DESCRIPTOR.message_types_by_name['ListDataPipelinesResponse']
_CREATEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataPipelineRequest']
_CREATEDATAPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['CreateDataPipelineResponse']
_UPDATEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRequest']
_UPDATEDATAPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataPipelineResponse']
_GETDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetDataPipelineRequest']
_GETDATAPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['GetDataPipelineResponse']
_RUNDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['RunDataPipelineRequest']
_RUNDATAPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['RunDataPipelineResponse']
_DELETEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRequest']
_DELETEDATAPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataPipelineResponse']
ListDataPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelinesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPIPELINESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest)
  })
_sym_db.RegisterMessage(ListDataPipelinesRequest)
_sym_db.RegisterMessage(ListDataPipelinesRequest.LabelsEntry)

ListDataPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesResponse)
  })
_sym_db.RegisterMessage(ListDataPipelinesResponse)

CreateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRequest)

CreateDataPipelineResponse = _reflection.GeneratedProtocolMessageType('CreateDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineResponse)
  })
_sym_db.RegisterMessage(CreateDataPipelineResponse)

UpdateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRequest)

UpdateDataPipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineResponse)
  })
_sym_db.RegisterMessage(UpdateDataPipelineResponse)

GetDataPipelineRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRequest)

GetDataPipelineResponse = _reflection.GeneratedProtocolMessageType('GetDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineResponse)
  })
_sym_db.RegisterMessage(GetDataPipelineResponse)

RunDataPipelineRequest = _reflection.GeneratedProtocolMessageType('RunDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineRequest)
  })
_sym_db.RegisterMessage(RunDataPipelineRequest)

RunDataPipelineResponse = _reflection.GeneratedProtocolMessageType('RunDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineResponse)
  })
_sym_db.RegisterMessage(RunDataPipelineResponse)

DeleteDataPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRequest)

DeleteDataPipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineResponse)
  })
_sym_db.RegisterMessage(DeleteDataPipelineResponse)

_DATAPIPELINESERVICE = DESCRIPTOR.services_by_name['DataPipelineService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/metaprov/modelaapi/services/datapipeline/v1'
  _LISTDATAPIPELINESREQUEST_LABELSENTRY._options = None
  _LISTDATAPIPELINESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATAPIPELINESERVICE.methods_by_name['ListDataPipelines']._options = None
  _DATAPIPELINESERVICE.methods_by_name['ListDataPipelines']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/datapipelines/{namespace}'
  _DATAPIPELINESERVICE.methods_by_name['CreateDataPipeline']._options = None
  _DATAPIPELINESERVICE.methods_by_name['CreateDataPipeline']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/datapipelines:\001*'
  _DATAPIPELINESERVICE.methods_by_name['GetDataPipeline']._options = None
  _DATAPIPELINESERVICE.methods_by_name['GetDataPipeline']._serialized_options = b'\202\323\344\223\002&\022$/v1/datapipelines/{namespace}/{name}'
  _DATAPIPELINESERVICE.methods_by_name['UpdateDataPipeline']._options = None
  _DATAPIPELINESERVICE.methods_by_name['UpdateDataPipeline']._serialized_options = b'\202\323\344\223\002U\032P/v1/datapipelines/{datapipeline.metadata.namespace}/{datapipeline.metadata.name}:\001*'
  _DATAPIPELINESERVICE.methods_by_name['DeleteDataPipeline']._options = None
  _DATAPIPELINESERVICE.methods_by_name['DeleteDataPipeline']._serialized_options = b'\202\323\344\223\002&*$/v1/datapipelines/{namespace}/{name}'
  _DATAPIPELINESERVICE.methods_by_name['RunDataPipeline']._options = None
  _DATAPIPELINESERVICE.methods_by_name['RunDataPipeline']._serialized_options = b'\202\323\344\223\002*\"(/v1/datapipelines/{namespace}/{name}:run'
  _LISTDATAPIPELINESREQUEST._serialized_start=268
  _LISTDATAPIPELINESREQUEST._serialized_end=527
  _LISTDATAPIPELINESREQUEST_LABELSENTRY._serialized_start=482
  _LISTDATAPIPELINESREQUEST_LABELSENTRY._serialized_end=527
  _LISTDATAPIPELINESRESPONSE._serialized_start=530
  _LISTDATAPIPELINESRESPONSE._serialized_end=677
  _CREATEDATAPIPELINEREQUEST._serialized_start=679
  _CREATEDATAPIPELINEREQUEST._serialized_end=796
  _CREATEDATAPIPELINERESPONSE._serialized_start=798
  _CREATEDATAPIPELINERESPONSE._serialized_end=826
  _UPDATEDATAPIPELINEREQUEST._serialized_start=829
  _UPDATEDATAPIPELINEREQUEST._serialized_end=994
  _UPDATEDATAPIPELINERESPONSE._serialized_start=996
  _UPDATEDATAPIPELINERESPONSE._serialized_end=1024
  _GETDATAPIPELINEREQUEST._serialized_start=1026
  _GETDATAPIPELINEREQUEST._serialized_end=1083
  _GETDATAPIPELINERESPONSE._serialized_start=1086
  _GETDATAPIPELINERESPONSE._serialized_end=1215
  _RUNDATAPIPELINEREQUEST._serialized_start=1217
  _RUNDATAPIPELINEREQUEST._serialized_end=1274
  _RUNDATAPIPELINERESPONSE._serialized_start=1276
  _RUNDATAPIPELINERESPONSE._serialized_end=1401
  _DELETEDATAPIPELINEREQUEST._serialized_start=1403
  _DELETEDATAPIPELINEREQUEST._serialized_end=1463
  _DELETEDATAPIPELINERESPONSE._serialized_start=1465
  _DELETEDATAPIPELINERESPONSE._serialized_end=1493
  _DATAPIPELINESERVICE._serialized_start=1496
  _DATAPIPELINESERVICE._serialized_end=2940
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/cronprediction/v1/cronprediction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMgithub.com/metaprov/modelaapi/services/cronprediction/v1/cronprediction.proto\x12\x38github.com.metaprov.modelaapi.services.cronprediction.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\x89\x02\n\x1aListCronPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12p\n\x06labels\x18\x02 \x03(\x0b\x32`.github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x1bListCronPredictionsResponse\x12\x66\n\x0f\x63ronpredictions\x18\x01 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPredictionList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1e\n\x1c\x43reateCronPredictionResponse\"\x80\x01\n\x1b\x43reateCronPredictionRequest\x12\x61\n\x0e\x63ronprediction\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\xb0\x01\n\x1bUpdateCronPredictionRequest\x12\x61\n\x0e\x63ronprediction\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1e\n\x1cUpdateCronPredictionResponse\";\n\x18GetCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8c\x01\n\x19GetCronPredictionResponse\x12\x61\n\x0e\x63ronprediction\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\x12\x0c\n\x04yaml\x18\x02 \x01(\t\">\n\x1b\x44\x65leteCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteCronPredictionResponse\"=\n\x1aPauseCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bPauseCronPredictionResponse\">\n\x1bResumeCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1e\n\x1cResumeCronPredictionResponse\"}\n\x18RunCronPredictionRequest\x12\x61\n\x0e\x63ronprediction\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x1b\n\x19RunCronPredictionResponse2\xa0\x0f\n\x15\x43ronPredictionService\x12\xeb\x01\n\x13ListCronPredictions\x12T.github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest\x1aU.github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/cronpredictions/{namespace}\x12\xe5\x01\n\x14\x43reateCronPrediction\x12U.github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionRequest\x1aV.github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/cronpredictions:\x01*\x12\xe0\x01\n\x11GetCronPrediction\x12R.github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionRequest\x1aS.github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/cronpredictions/{name}\x12\x84\x02\n\x14UpdateCronPrediction\x12U.github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionRequest\x1aV.github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionResponse\"=\x82\xd3\xe4\x93\x02\x37\x1a\x32/v1/cronpredictions/{cronprediction.metadata.name}:\x01*\x12\xe9\x01\n\x14\x44\x65leteCronPrediction\x12U.github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionRequest\x1aV.github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionResponse\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/cronpredictions/{name}\x12\xec\x01\n\x13PauseCronPrediction\x12T.github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionRequest\x1aU.github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionResponse\"(\x82\xd3\xe4\x93\x02\"\" /v1/cronpredictions/{name}:pause\x12\xf0\x01\n\x14ResumeCronPrediction\x12U.github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionRequest\x1aV.github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionResponse\")\x82\xd3\xe4\x93\x02#\"!/v1/cronpredictions/{name}:resume\x12\xf8\x01\n\rRunPrediction\x12R.github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionRequest\x1aS.github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionResponse\">\x82\xd3\xe4\x93\x02\x38\"6/v1/cronpredictions/{cronprediction.metadata.name}:runB:Z8github.com/metaprov/modelaapi/services/cronprediction/v1b\x06proto3')



_LISTCRONPREDICTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListCronPredictionsRequest']
_LISTCRONPREDICTIONSREQUEST_LABELSENTRY = _LISTCRONPREDICTIONSREQUEST.nested_types_by_name['LabelsEntry']
_LISTCRONPREDICTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListCronPredictionsResponse']
_CREATECRONPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateCronPredictionResponse']
_CREATECRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['CreateCronPredictionRequest']
_UPDATECRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateCronPredictionRequest']
_UPDATECRONPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateCronPredictionResponse']
_GETCRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['GetCronPredictionRequest']
_GETCRONPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['GetCronPredictionResponse']
_DELETECRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteCronPredictionRequest']
_DELETECRONPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteCronPredictionResponse']
_PAUSECRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['PauseCronPredictionRequest']
_PAUSECRONPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['PauseCronPredictionResponse']
_RESUMECRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['ResumeCronPredictionRequest']
_RESUMECRONPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['ResumeCronPredictionResponse']
_RUNCRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['RunCronPredictionRequest']
_RUNCRONPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['RunCronPredictionResponse']
ListCronPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListCronPredictionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCRONPREDICTIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCRONPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest)
  })
_sym_db.RegisterMessage(ListCronPredictionsRequest)
_sym_db.RegisterMessage(ListCronPredictionsRequest.LabelsEntry)

ListCronPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListCronPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsResponse)
  })
_sym_db.RegisterMessage(ListCronPredictionsResponse)

CreateCronPredictionResponse = _reflection.GeneratedProtocolMessageType('CreateCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionResponse)
  })
_sym_db.RegisterMessage(CreateCronPredictionResponse)

CreateCronPredictionRequest = _reflection.GeneratedProtocolMessageType('CreateCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionRequest)
  })
_sym_db.RegisterMessage(CreateCronPredictionRequest)

UpdateCronPredictionRequest = _reflection.GeneratedProtocolMessageType('UpdateCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionRequest)
  })
_sym_db.RegisterMessage(UpdateCronPredictionRequest)

UpdateCronPredictionResponse = _reflection.GeneratedProtocolMessageType('UpdateCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionResponse)
  })
_sym_db.RegisterMessage(UpdateCronPredictionResponse)

GetCronPredictionRequest = _reflection.GeneratedProtocolMessageType('GetCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionRequest)
  })
_sym_db.RegisterMessage(GetCronPredictionRequest)

GetCronPredictionResponse = _reflection.GeneratedProtocolMessageType('GetCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionResponse)
  })
_sym_db.RegisterMessage(GetCronPredictionResponse)

DeleteCronPredictionRequest = _reflection.GeneratedProtocolMessageType('DeleteCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionRequest)
  })
_sym_db.RegisterMessage(DeleteCronPredictionRequest)

DeleteCronPredictionResponse = _reflection.GeneratedProtocolMessageType('DeleteCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionResponse)
  })
_sym_db.RegisterMessage(DeleteCronPredictionResponse)

PauseCronPredictionRequest = _reflection.GeneratedProtocolMessageType('PauseCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionRequest)
  })
_sym_db.RegisterMessage(PauseCronPredictionRequest)

PauseCronPredictionResponse = _reflection.GeneratedProtocolMessageType('PauseCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionResponse)
  })
_sym_db.RegisterMessage(PauseCronPredictionResponse)

ResumeCronPredictionRequest = _reflection.GeneratedProtocolMessageType('ResumeCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionRequest)
  })
_sym_db.RegisterMessage(ResumeCronPredictionRequest)

ResumeCronPredictionResponse = _reflection.GeneratedProtocolMessageType('ResumeCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionResponse)
  })
_sym_db.RegisterMessage(ResumeCronPredictionResponse)

RunCronPredictionRequest = _reflection.GeneratedProtocolMessageType('RunCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionRequest)
  })
_sym_db.RegisterMessage(RunCronPredictionRequest)

RunCronPredictionResponse = _reflection.GeneratedProtocolMessageType('RunCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionResponse)
  })
_sym_db.RegisterMessage(RunCronPredictionResponse)

_CRONPREDICTIONSERVICE = DESCRIPTOR.services_by_name['CronPredictionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/metaprov/modelaapi/services/cronprediction/v1'
  _LISTCRONPREDICTIONSREQUEST_LABELSENTRY._options = None
  _LISTCRONPREDICTIONSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CRONPREDICTIONSERVICE.methods_by_name['ListCronPredictions']._options = None
  _CRONPREDICTIONSERVICE.methods_by_name['ListCronPredictions']._serialized_options = b'\202\323\344\223\002!\022\037/v1/cronpredictions/{namespace}'
  _CRONPREDICTIONSERVICE.methods_by_name['CreateCronPrediction']._options = None
  _CRONPREDICTIONSERVICE.methods_by_name['CreateCronPrediction']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/cronpredictions:\001*'
  _CRONPREDICTIONSERVICE.methods_by_name['GetCronPrediction']._options = None
  _CRONPREDICTIONSERVICE.methods_by_name['GetCronPrediction']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/cronpredictions/{name}'
  _CRONPREDICTIONSERVICE.methods_by_name['UpdateCronPrediction']._options = None
  _CRONPREDICTIONSERVICE.methods_by_name['UpdateCronPrediction']._serialized_options = b'\202\323\344\223\0027\0322/v1/cronpredictions/{cronprediction.metadata.name}:\001*'
  _CRONPREDICTIONSERVICE.methods_by_name['DeleteCronPrediction']._options = None
  _CRONPREDICTIONSERVICE.methods_by_name['DeleteCronPrediction']._serialized_options = b'\202\323\344\223\002\034*\032/v1/cronpredictions/{name}'
  _CRONPREDICTIONSERVICE.methods_by_name['PauseCronPrediction']._options = None
  _CRONPREDICTIONSERVICE.methods_by_name['PauseCronPrediction']._serialized_options = b'\202\323\344\223\002\"\" /v1/cronpredictions/{name}:pause'
  _CRONPREDICTIONSERVICE.methods_by_name['ResumeCronPrediction']._options = None
  _CRONPREDICTIONSERVICE.methods_by_name['ResumeCronPrediction']._serialized_options = b'\202\323\344\223\002#\"!/v1/cronpredictions/{name}:resume'
  _CRONPREDICTIONSERVICE.methods_by_name['RunPrediction']._options = None
  _CRONPREDICTIONSERVICE.methods_by_name['RunPrediction']._serialized_options = b'\202\323\344\223\0028\"6/v1/cronpredictions/{cronprediction.metadata.name}:run'
  _LISTCRONPREDICTIONSREQUEST._serialized_start=279
  _LISTCRONPREDICTIONSREQUEST._serialized_end=544
  _LISTCRONPREDICTIONSREQUEST_LABELSENTRY._serialized_start=499
  _LISTCRONPREDICTIONSREQUEST_LABELSENTRY._serialized_end=544
  _LISTCRONPREDICTIONSRESPONSE._serialized_start=547
  _LISTCRONPREDICTIONSRESPONSE._serialized_end=705
  _CREATECRONPREDICTIONRESPONSE._serialized_start=707
  _CREATECRONPREDICTIONRESPONSE._serialized_end=737
  _CREATECRONPREDICTIONREQUEST._serialized_start=740
  _CREATECRONPREDICTIONREQUEST._serialized_end=868
  _UPDATECRONPREDICTIONREQUEST._serialized_start=871
  _UPDATECRONPREDICTIONREQUEST._serialized_end=1047
  _UPDATECRONPREDICTIONRESPONSE._serialized_start=1049
  _UPDATECRONPREDICTIONRESPONSE._serialized_end=1079
  _GETCRONPREDICTIONREQUEST._serialized_start=1081
  _GETCRONPREDICTIONREQUEST._serialized_end=1140
  _GETCRONPREDICTIONRESPONSE._serialized_start=1143
  _GETCRONPREDICTIONRESPONSE._serialized_end=1283
  _DELETECRONPREDICTIONREQUEST._serialized_start=1285
  _DELETECRONPREDICTIONREQUEST._serialized_end=1347
  _DELETECRONPREDICTIONRESPONSE._serialized_start=1349
  _DELETECRONPREDICTIONRESPONSE._serialized_end=1379
  _PAUSECRONPREDICTIONREQUEST._serialized_start=1381
  _PAUSECRONPREDICTIONREQUEST._serialized_end=1442
  _PAUSECRONPREDICTIONRESPONSE._serialized_start=1444
  _PAUSECRONPREDICTIONRESPONSE._serialized_end=1473
  _RESUMECRONPREDICTIONREQUEST._serialized_start=1475
  _RESUMECRONPREDICTIONREQUEST._serialized_end=1537
  _RESUMECRONPREDICTIONRESPONSE._serialized_start=1539
  _RESUMECRONPREDICTIONRESPONSE._serialized_end=1569
  _RUNCRONPREDICTIONREQUEST._serialized_start=1571
  _RUNCRONPREDICTIONREQUEST._serialized_end=1696
  _RUNCRONPREDICTIONRESPONSE._serialized_start=1698
  _RUNCRONPREDICTIONRESPONSE._serialized_end=1725
  _CRONPREDICTIONSERVICE._serialized_start=1728
  _CRONPREDICTIONSERVICE._serialized_end=3680
# @@protoc_insertion_point(module_scope)
